.. -*- coding: utf-8 -*-
.. :Progetto:  SoL
.. :Creato:    mer 09 lug 2014 10:13:27 CEST
.. :Autore:    Lele Gaifax <lele@metapensiero.it>
.. :Licenza:   GNU General Public License version 3 or later
..

======================================
 :mod:`sol.models.utils` -- Utilities
======================================

.. automodule:: sol.models.utils

.. autofunction:: asunicode
.. autofunction:: normalize
.. autofunction:: njoin
.. autofunction:: entity_from_primary_key
.. autofunction:: table_from_primary_key
